Struct minedmap_types::BlockCoord
source · pub struct BlockCoord<const AXIS: u8>(pub u8);Expand description
A block coordinate relative to a chunk
Tuple Fields
0: u8Implementations
sourceimpl<const AXIS: u8> BlockCoord<AXIS>
impl<const AXIS: u8> BlockCoord<AXIS>
sourcepub fn new<T: TryInto<u8>>(value: T) -> Self
pub fn new<T: TryInto<u8>>(value: T) -> Self
Constructs a new value
Will panic if the value is not in the valid range
sourcepub fn iter(
) -> impl Iterator<Item = BlockCoord<AXIS>> + DoubleEndedIterator + ExactSizeIterator + FusedIterator + Clone + Debug
pub fn iter( ) -> impl Iterator<Item = BlockCoord<AXIS>> + DoubleEndedIterator + ExactSizeIterator + FusedIterator + Clone + Debug
Returns an iterator over all possible values of the type