pub struct LayerBlockCoords {
    pub x: BlockX,
    pub z: BlockZ,
}
X and Z coordinates of a block in a chunk

Fields

x: BlockX

The X coordinate

z: BlockZ

The Z coordinate

Implementations

source

impl LayerBlockCoords

source

pub fn offset(&self) -> usize

Computes a block’s offset in various data structures

Many chunk data structures store block and biome data in the same order. This method computes the offset at which the data for the block at a given coordinate is stored.