pub struct SectionBlockCoords {
    pub xz: LayerBlockCoords,
    pub y: BlockY,
}
X, Y and Z coordinates of a block in a chunk section

Fields

xz: LayerBlockCoords

The X and Z coordinates

y: BlockY

The Y coordinate

Implementations

source

impl SectionBlockCoords

source

pub fn offset(&self) -> usize

Computes a block’s offset in various data structures

Many chunk data structures store block and biome data in the same order. This method computes the offset at which the data for the block at a given coordinate is stored.